==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicMenuBarUI__24ContainerHandler.h <==
// public class javax.swing.plaf.basic.BasicMenuBarUI$ContainerHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fd588593fed821d9 javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler_H_
#define _JC_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_ContainerEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$refs	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vmethods	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtable	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtype	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$method$_init$5b6f7a544ee5494b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object *, struct _jc_javax_swing_plaf_basic_BasicMenuBarUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$method$componentAdded$c1a226b52e818d0c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$method$componentRemoved$0b1853b514a86e99(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$method_info$componentAdded$c1a226b52e818d0c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$method_info$componentRemoved$0b1853b514a86e99;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vmethods {
	void	(*componentAdded$c1a226b52e818d0c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *);
	void	(*componentRemoved$0b1853b514a86e99)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vmethods	javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicMenuBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$refs {
    _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_refs	javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_nonrefs	javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object {
	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtype _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicMenuBarUI__24ContainerHandler.h <==
// public class javax.swing.plaf.basic.BasicMenuBarUI$ContainerHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fd588593fed821d9 javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler_H_
#define _JC_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_ContainerEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$refs	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vmethods	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtable	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtype	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$method$_init$5b6f7a544ee5494b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object *, struct _jc_javax_swing_plaf_basic_BasicMenuBarUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$method$componentAdded$c1a226b52e818d0c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$method$componentRemoved$0b1853b514a86e99(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$method_info$componentAdded$c1a226b52e818d0c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$method_info$componentRemoved$0b1853b514a86e99;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vmethods {
	void	(*componentAdded$c1a226b52e818d0c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
	void	(*componentRemoved$0b1853b514a86e99)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vmethods	javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicMenuBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$refs {
    _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_refs	javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$sub_nonrefs	javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$object {
	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$vtype _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicMenuBarUI__24ContainerHandler_H_ */
